#!/bin/bash -u

# setup args in the right order for making getopt evaluation
# nice and easy.  You'll need to read the manpages for more info
args=$(getopt -o h -- "$@")
eval set -- "$args"

###########################################################
usage() {
    echo ''           >&2
    echo "$0 <file listing ntp servers>"         >&2
    echo "   Set /etc/ntpd.conf for use at Fermilab">&2
    echo ''          >&2
    exit 1
}

###########################################################
for arg in $@; do
    case $1 in
        -- )
            # end of getopt args, shift off the -- and get out of the loop
            shift
            break 2
           ;;
         -h )
            # get help
            usage
           ;;
    esac
done

FILENAME=${1:-}
if [[ ! -f ${FILENAME} ]]; then
    usage
fi
NTPSERVERS=$(cat ${FILENAME})

which augtool >/dev/null 2>&1
if [[ $? -ne 0 ]]; then
    echo "Could not find augtool" >&2
    exit 1
fi

# Save the config files!
if [[ -f /etc/ntp.conf ]]; then
    cp -pa /etc/ntp.conf /etc/ntp.conf.rpmsave
fi

TMPFILE=$(mktemp)
    cat > ${TMPFILE} <<SETUP
set /augeas/load/Ntp/incl "/etc/ntp.conf"
load
SETUP

# don't use TUV's ntp servers, we have our own
grep -v '#' /etc/ntp.conf | grep 'rhel.pool.ntp.org' 2>&1 >/dev/null
if [[ $? -eq 0 ]]; then
    cat >> ${TMPFILE} <<RMTUVNTPSERVERS
rm /files/etc/ntp.conf/server[ . =~ regexp(".*rhel.pool.ntp.org")]
RMTUVNTPSERVERS
fi

# we want honesty rather than calculated expectations, don't fudge the numbers
grep -v '#' /etc/ntp.conf | grep 'fudge' 2>&1 >/dev/null
if [[ $? -eq 0 ]]; then
    cat >> ${TMPFILE} <<RMFUDGE
rm /files/etc/ntp.conf/fudge
RMFUDGE
fi

# enable checking our NTP servers
someint=9999
for system in ${NTPSERVERS}; do
    someint=$(expr ${someint} + 1)
    grep ${system} /etc/ntp.conf >/dev/null 2>&1
    if [[ $? -ne 0 ]]; then
        cat >> ${TMPFILE} <<SETSERVER
set /files/etc/ntp.conf/server[${someint}] ${system}
SETSERVER
    fi
done

echo "save" >> ${TMPFILE}

augtool --noload <${TMPFILE} >/dev/null
RC=$?

chmod 644 /etc/ntp.conf
restorecon -F /etc/ntp.conf

rm -f ${TMPFILE}

exit ${RC}
